sentinels

package
v0.0.0-...-7af5547 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 18, 2022 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SimpleSentinel

type SimpleSentinel struct {
	Command string // the command, e.g. 'echo "Rumplestiltskin"'
	Value   string // the sentinel value to look for, e.g. 'Rumplestiltskin'.
	// contains filtered or unexported fields
}

SimpleSentinel asserts Found if it sees Value anywhere in the output of Command.

func (*SimpleSentinel) Found

func (c *SimpleSentinel) Found() bool

Found returns true if Value found.

func (*SimpleSentinel) Line

func (c *SimpleSentinel) Line() string

func (*SimpleSentinel) Match

func (c *SimpleSentinel) Match() string

Match returns the most recent match.

func (*SimpleSentinel) Write

func (c *SimpleSentinel) Write(b []byte) (int, error)

Write looks for Value at the end of the line (so it had better be unambiguous).

Jump to